@@ -38,7 +38,7 @@ from qff.tools.kshow import kshow
 # subprocess.Popen
 
 __all__ = ['Command', 'RunCommand', 'SimTradeCommand', 'ResumeCommand', 'CreateCommand',
-           'ConfigCommand', 'SaveCommand', 'DbinfoCommand', 'KshowCommand']
+           'ConfigCommand', 'SaveCommand', 'DropCommand', 'DbinfoCommand', 'KshowCommand']
 
 
 class Command:
@@ -81,7 +81,7 @@ class RunCommand(Command):
         self.parser.add_argument("strategy_file", help="策略文件名称路径", nargs='?')
         self.parser.add_argument("-n", "--name", help="策略名称,默认为策略文件名", metavar="<name>")
         self.parser.add_argument("-rt", "--run-type", choices=['bt', 'sim'], default='bt',
-                                 help="设置策略运行类型,bt为回测,st为模拟交易,默认为bt")
+                                 help="设置策略运行类型,bt为回测,sim为模拟交易,默认为bt")
 
         self.parser.add_argument("-f", "--freq", choices=['day', 'min', 'tick'], default='day',
                                  help="设置回测执行频率,可选(day, min, tick),默认day")
@@ -351,6 +351,28 @@ class SaveCommand(Command):
         qff_save(args.subcommand)
 
 
+class DropCommand(Command):
+    """
+    删除指定的数据表，用于数据维护，数据表名称可通过qff dbinfo查看。
+    """
+    usage = f"\nqff drop <table_name>"
+    summary = "删除指定的数据表"
+
+    def __init__(self, sub_parser):
+        super().__init__('drop', sub_parser)
+
+    def add_options(self) -> None:
+        self.parser.add_argument("table_name", help="需要删除的数据表名称", nargs='?')
+
+    def main(self, args):
+        from qff.store.update_all import qff_drop
+
+        if args.table_name is None:
+            self.parser.print_help()
+        else:
+            qff_drop(args.table_name)
+
+
 class DbinfoCommand(Command):
     """
     显示qff数据库的当前信息
